# wilfred
# https://github.com/wilfred-dev/wilfred
# (c) Vilhelm Prytz 2020

import docker


def docker_client(base_url=None):
    """returns client object used for Docker socket communication

    :param str base_url: Base URL for Docker socket. Uses env if None."""

    client = docker.DockerClient(base_url=base_url) if base_url else docker.from_env()

    return client



from setuptools import setup, find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="wilfred",  # Replace with your own username
    version="0.0.3-alpha1",
    author="Vilhelm Prytz",
    author_email="vlhelm@prytznet.se",
    description="A CLI for managing game servers using Docker.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/wilfred-dev/wilfred",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: Unix",
    ],
    python_requires=">=3.6",
    install_requires=["docker", "click", "colorama"],
    entry_points={"console_scripts": ["wilfred=wilfred.wilfred:main",]},
)



# wilfred
# https://github.com/wilfred-dev/wilfred
# (c) Vilhelm Prytz 2020

import click

from docker_conn import docker_client
from version import version

client = docker_client()


def print_version(ctx, param, value):
    if not value or ctx.resilient_parsing:
        return
    click.echo(f"✨ wilfred version {version}")
    ctx.exit()


def main():
    cli()


@click.group()
@click.option(
    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
)
def cli():
    """
    A CLI for managing game servers using Docker.

    ⚠️  This is still experimental, features not be implementet yet or broken.
    """

    pass


@cli.command()
def servers():
    """list of all servers"""

    try:
        containers = client.containers.list()
    except Exception as e:
        click.echo(
            click.style("❌ ")
            + click.style("unable to communicate with docker - ", bold=True)
            + str(e),
            err=True,
        )
        exit(1)

    pass


@cli.command()
def create():
    """create a new server"""

    pass


@cli.command()
def delete():
    """delete existing server"""

    pass


if __name__ == "__main__":
    main()
